@@ -158,8 +158,8 @@ public:
     FakeInput *remoteInterface = nullptr;
 };
 
-PlasmaScreencastV1Session::PlasmaScreencastV1Session(Server *server)
-    : AbstractSession(server)
+PlasmaScreencastV1Session::PlasmaScreencastV1Session()
+    : AbstractSession()
     , d(std::make_unique<Private>())
 {
     d->remoteInterface = new FakeInput();
@@ -221,14 +221,20 @@ void PlasmaScreencastV1Session::sendEvent(const std::shared_ptr<QEvent> &event)
     }
     case QEvent::MouseMove: {
         auto me = std::static_pointer_cast<QMouseEvent>(event);
-        auto position = me->globalPosition();
+        auto position = me->position();
         auto logicalPosition = QPointF{(position.x() / size().width()) * logicalSize().width(), (position.y() / size().height()) * logicalSize().height()};
         d->remoteInterface->pointer_motion_absolute(logicalPosition.x(), logicalPosition.y());
         break;
     }
     case QEvent::Wheel: {
         auto we = std::static_pointer_cast<QWheelEvent>(event);
-        d->remoteInterface->axis(0, we->angleDelta().y() / 120);
+        auto delta = we->angleDelta();
+        if (delta.y() != 0) {
+            d->remoteInterface->axis(WL_POINTER_AXIS_VERTICAL_SCROLL, delta.y() / 120);
+        }
+        if (delta.x() != 0) {
+            d->remoteInterface->axis(WL_POINTER_AXIS_HORIZONTAL_SCROLL, delta.x() / 120);
+        }
         break;
     }
     case QEvent::KeyPress:
