@@ -14,7 +14,7 @@
 #include <KSharedConfig>
 
 #include "PortalSession_p.h"
-#include "VideoStream.h"
+#include "VideoFrame.h"
 #include "krdp_logging.h"
 #include "xdp_dbus_remotedesktop_interface.h"
 #include "xdp_dbus_screencast_interface.h"
@@ -83,12 +83,10 @@ QString createHandleToken()
     return QStringLiteral("krdp%1").arg(QRandomGenerator::global()->generate());
 }
 
-PortalSession::PortalSession(Server *server)
-    : AbstractSession(server)
+PortalSession::PortalSession()
+    : AbstractSession()
     , d(std::make_unique<Private>())
 {
-    d->server = server;
-
     d->remoteInterface = std::make_unique<OrgFreedesktopPortalRemoteDesktopInterface>(dbusService, dbusPath, QDBusConnection::sessionBus());
     d->screencastInterface = std::make_unique<OrgFreedesktopPortalScreenCastInterface>(dbusService, dbusPath, QDBusConnection::sessionBus());
 
@@ -152,14 +150,20 @@ void PortalSession::sendEvent(const std::shared_ptr<QEvent> &event)
     }
     case QEvent::MouseMove: {
         auto me = std::static_pointer_cast<QMouseEvent>(event);
-        auto position = me->globalPosition();
+        auto position = me->position();
         auto logicalPosition = QPointF{(position.x() / size().width()) * logicalSize().width(), (position.y() / size().height()) * logicalSize().height()};
         d->remoteInterface->NotifyPointerMotionAbsolute(d->sessionPath, QVariantMap{}, encodedStream->nodeId(), logicalPosition.x(), logicalPosition.y());
         break;
     }
     case QEvent::Wheel: {
         auto we = std::static_pointer_cast<QWheelEvent>(event);
-        d->remoteInterface->NotifyPointerAxisDiscrete(d->sessionPath, QVariantMap{}, 0, we->angleDelta().y() / 120);
+        auto delta = we->angleDelta();
+        if (delta.y() != 0) {
+            d->remoteInterface->NotifyPointerAxisDiscrete(d->sessionPath, QVariantMap{}, 0 /* Vertical */, delta.y() / 120);
+        }
+        if (delta.x() != 0) {
+            d->remoteInterface->NotifyPointerAxisDiscrete(d->sessionPath, QVariantMap{}, 1 /* Horizontal */, delta.x() / 120);
+        }
         break;
     }
     case QEvent::KeyPress:
@@ -196,7 +200,8 @@ void PortalSession::onCreateSession(uint code, const QVariantMap &result)
         {QStringLiteral("handle_token"), createHandleToken()},
         {QStringLiteral("persist_mode"), PermissionsPersistUntilExplicitlyRevoked},
     };
-    KConfigGroup restorationGroup = KSharedConfig::openStateConfig()->group(QStringLiteral("General"));
+    // name is set explicitly as this is also used by the KCM
+    KConfigGroup restorationGroup = KSharedConfig::openStateConfig(QStringLiteral("krdp-serverstaterc"))->group(QStringLiteral("General"));
     QString restoreToken = restorationGroup.readEntry(QStringLiteral("restorationToken"));
 
     // this is a compatibility path for krdp < 6.3 that used a different name and in .config
@@ -260,7 +265,7 @@ void KRdp::PortalSession::onSessionStarted(uint code, const QVariantMap &result)
         return;
     }
 
-    KConfigGroup restorationGroup = KSharedConfig::openStateConfig()->group(QStringLiteral("General"));
+    KConfigGroup restorationGroup = KSharedConfig::openStateConfig(QStringLiteral("krdp-serverstaterc"))->group(QStringLiteral("General"));
     restorationGroup.writeEntry("restorationToken", result.value(QStringLiteral("restore_token")));
 
     const auto streams = qdbus_cast<QList<PortalSessionStream>>(result.value(QStringLiteral("streams")));
